version 14

* FIGURE S11 Effects of Selected Attributes on Probability of Economic Program or Fiscal Scheme Being Selected by Identity

******** Economic policy conjoint
******** Marginal effect of attributes at different identity positioning of respondents
use dataset2.dta, clear

* create identity variable
* D027_04	L'adesione all'Unione Europea comporta la perdita della nostra identita' culturale	EU national identity
drop if D027_04==12

rename D027_04 identity

reg Y1 i.unemployment i.inflation i.taxsoc i.euro i.eucontrol i.eutaxsoc ///
i.unemployment##c.identity i.inflation##c.identity i.taxsoc##c.identity i.euro##c.identity i.eucontrol##c.identity i.eutaxsoc##c.identity, cl(ID)

estimates save m1.ster, replace

**********  EURO
* Ditch Euro
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b45, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 11 {
{
generate x_betahat0 = MG_b12 
generate x_betahat1 = MG_b13 + MG_b36*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.1
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2)) xtitle(" ", size(2)) ///
xlabel(1 "s. disagree" 26 "disagree" 51 "neither" 76 "agree" 101 "s. agree", labsize(2)) ylabel(-0.1 "-0.1" -0.05 "-0.05" 0 "0", labsize(2)) title("Economic policy: Ditch the euro", size(2)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(figS11_1, replace)

**********  EU TAXSPEND
* Additional EU tax-spend
restore, not
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b45, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 11 {
{
generate x_betahat0 = MG_b17 
generate x_betahat1 = MG_b18 + MG_b43*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.1
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2)) xtitle(" ", size(2)) ///
xlabel(1 "s. disagree" 26 "disagree" 51 "neither" 76 "agree" 101 "s. agree", labsize(2)) ylabel(-0.06 "-0.06" -0.04 "-0.04" -0.02 "-0.02" 0 "0", labsize(2)) title("Economic policy: Additional EU tax-spend", size(2)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(figS11_2, replace)

* Alternate EU tax-spend
restore, not
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b45, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 11 {
{
generate x_betahat0 = MG_b17 
generate x_betahat1 = MG_b19 + MG_b44*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.1
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2)) xtitle("EU leads to loss of identity", size(2)) ///
xlabel(1 "s. disagree" 26 "disagree" 51 "neither" 76 "agree" 101 "s. agree", labsize(2)) ylabel(-0.04 "-0.04" -0.02 "-0.02" 0 "0" 0.01 "0.01", labsize(2)) title("Economic policy: Alternate EU tax-spend", size(2)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(figS11_3, replace)

******** Fiscal union conjoint
clear all
restore, not

******** Marginal effect of attributes at different identity positioning of respondents
use dataset2.dta, clear

* create identity variable
* Q164_W3_2015 Lei quanto si sente europeo? (identity4)
* do not know
drop if Q164_W3_2015==5
rename Q164_W3_2015 identity

reg FU1 i.taxrate i.taxtype i.spend i.spendtype i.spendinst i.contrinst ///
i.taxrate##c.identity i.taxtype##c.identity i.spend##c.identity i.spendtype##c.identity i.spendinst##c.identity i.contrinst##c.identity, cl(ID)
estimates save m1.ster, replace

**********  SPENDING INSTITUTION
* National Government
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b43, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 4 {
{
generate x_betahat0 = MG_b14 
generate x_betahat1 = MG_b15 + MG_b38*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.025
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2)) xtitle(" ", size(2)) ///
xlabel(1 "v. high" 41 "high" 81 "low" 121 "v. low", labsize(2)) ylabel(-0.04 "-0.04" -0.02 "-0.02" 0 "0" 0.02 "0.02" , labsize(2)) title("Fiscal union (spending authority): Government", size(2)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(figS11_4, replace)

**********  AUDITING INSTITUTION
* European Commission
restore, not
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b43, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 4 {
{
generate x_betahat0 = MG_b16 
generate x_betahat1 = MG_b17 + MG_b41*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.025
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2)) xtitle(" ", size(2)) ///
xlabel(1 "v. high" 41 "high" 81 "low" 121 "v. low", labsize(2)) ylabel(-0.05 "-0.05" -0.03 "-0.03" -0.01 "-0.01" 0 "0" 0.01 "0.01", labsize(2)) title("Fiscal union: European Commission auditing", size(2)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(figS11_5, replace)

* National Court of Auditors
restore, not
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b43, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 4 {
{
generate x_betahat0 = MG_b16 
generate x_betahat1 = MG_b18 + MG_b42*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.025
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2)) xtitle("Feeling European", size(2)) ///
xlabel(1 "v. high" 41 "high" 81 "low" 121 "v. low", labsize(2)) ylabel(-0.06 "-0.06" -0.04 "-0.04" -0.02 "-0.02" 0 "0" 0.02 "0.02", labsize(2)) title("Fiscal union: Italian auditors court", size(2)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(figS11_6, replace)

*****  Combine graphs

graph combine figS11_1.gph figS11_4.gph figS11_2.gph figS11_5.gph figS11_3.gph figS11_6.gph , col(2) graphregion(fcolor(white)) imargin(0 0 0 0) saving(figure_s11, replace)
