version 14

* FIGURE S9 Effects of Selected Attributes on Probability of Economic Program Being Selected by Ideology
use dataset2.dta, clear

* creating left-right variable
******** Marginal effect of attributes at different left right self positioning of respondents
* do not position themselves
drop if D028_01==12
* do not know
drop if D028_01==13
rename D028_01 lr

reg Y1 i.unemployment i.inflation i.taxsoc i.euro i.eucontrol i.eutaxsoc ///
i.unemployment##c.lr i.inflation##c.lr i.taxsoc##c.lr i.euro##c.lr i.eucontrol##c.lr i.eutaxsoc##c.lr, cl(ID)

estimates save m1.ster, replace

**********  EU TAXSPEND
* Additional EU tax-spend
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b45, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 11 {
{
generate x_betahat0 = MG_b17 
generate x_betahat1 = MG_b18 + MG_b43*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.1
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n

eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2.5)) xtitle("", size(2.5)) ///
xlabel(1 "left" 51 "centre" 101 "right", labsize(2.5)) ylabel(-0.06 "-0.06" -0.04 "-0.04" -0.02 "-0.02" 0 "0", labsize(2.5)) title("Economic policy: Additional EU tax-spend", size(2.5)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(figure_S9_up, replace)

**********  EURO
* Ditch Euro
estimates use m1.ster
est des

drawnorm MG_b1-MG_b45, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 11 {
{
generate x_betahat0 = MG_b12 
generate x_betahat1 = MG_b13 + MG_b36*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.1
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2.5)) xtitle("", size(2.5)) ///
xlabel(1 "left" 51 "centre" 101 "right", labsize(2.5)) ylabel(-0.15 "-0.15" -0.1 "-0.1" -0.05 "-0.05" 0 "0", labsize(2.5)) title(Economic policy: Ditch the euro, size(2.5)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(figure_S9_down, replace)


**********  Combine graphs

graph combine figure_S9_up.gph figure_S9_down.gph, col(1) graphregion(fcolor(white)) imargin(0 0 0 0) saving(figure_s9, replace)
